@@ -1,3 +1,4 @@
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef __WIN32__
@@ -341,7 +342,7 @@ int main (int argc, char **argv)
 	     argc--;
 	  }
      }
-
+   fprintf (stdout, "slsh: argv[0]=%s\n", argv[0]);
    if (-1 == SLang_set_argc_argv (argc, argv))
      return 1;
 
