@@ -1,5 +1,5 @@
 /* Array manipulation routines for S-Lang */
-/* Copyright (c) 1997, 1999 John E. Davis
+/* Copyright (c) 1997, 1999, 2001 John E. Davis
  * This file is part of the S-Lang library.
  *
  * You may distribute under the terms of either the GNU General Public
@@ -733,8 +733,7 @@ convert_nasty_index_objs (SLang_Array_Type *at,
 			  int *range_buf, int *range_delta_buf,
 			  int *max_dims,
 			  unsigned int *num_elements,
-			  int *is_array)
-
+			  int *is_array, int is_dim_array[SLARRAY_MAX_DIMS])
 {
    unsigned int i, total_num_elements;
    SLang_Array_Type *ind_at;
@@ -762,10 +761,12 @@ convert_nasty_index_objs (SLang_Array_Type *at,
 	     range_buf [i] = min_index = max_index = obj->v.int_val;
 	     max_dims [i] = 1;
 	     index_data[i] = range_buf + i;
+	     is_dim_array[i] = 0;
 	  }
 	else
 	  {
 	     *is_array = 1;
+	     is_dim_array[i] = 1;
 	     ind_at = obj->v.array_val;
 
 	     if (ind_at->flags & SLARR_DATA_VALUE_IS_RANGE)
@@ -902,10 +903,12 @@ aget_from_indices (SLang_Array_Type *at,
    int is_ptr, ret, is_array;
    char *new_data;
    SLang_Class_Type *cl;
+   int is_dim_array[SLARRAY_MAX_DIMS];
 
    if (-1 == convert_nasty_index_objs (at, index_objs, num_indices,
 				       index_data, range_buf, range_delta_buf,
-				       max_dims, &num_elements, &is_array))
+				       max_dims, &num_elements, &is_array,
+				       is_dim_array))
      return -1;
 
    is_ptr = (at->flags & SLARR_DATA_VALUE_IS_POINTER);
@@ -962,7 +965,7 @@ aget_from_indices (SLang_Array_Type *at,
 	/* Fixup dimensions on array */
 	for (i = 0; i < num_indices; i++)
 	  {
-	     if (max_dims[i] > 1)
+	     if (is_dim_array[i]) /* was: (max_dims[i] > 1) */
 	       {
 		  new_at->dims[num_dims] = max_dims[i];
 		  num_dims++;
@@ -1271,10 +1274,12 @@ aput_from_indices (SLang_Array_Type *at,
    char *data_to_put;
    unsigned int data_increment;
    SLang_Class_Type *cl;
+   int is_dim_array [SLARRAY_MAX_DIMS];
 
    if (-1 == convert_nasty_index_objs (at, index_objs, num_indices,
 				       index_data, range_buf, range_delta_buf,
-				       max_dims, &num_elements, &is_array))
+				       max_dims, &num_elements, &is_array,
+				       is_dim_array))
      return -1;
 
    cl = at->cl;
@@ -1289,7 +1294,7 @@ aput_from_indices (SLang_Array_Type *at,
    ret = -1;
 
    SLMEMSET((char *) map_indices, 0, sizeof(map_indices));
-   do
+   if (num_elements) do
      {
 	for (i = 0; i < num_indices; i++)
 	  {
@@ -2474,7 +2479,7 @@ static void array_map (void)
    unsigned int num_args;
    unsigned int i, i_control;
    SLang_Name_Type *nt;
-   unsigned int num_elements, increment;
+   unsigned int num_elements;
    SLang_Array_Type *at;
    char *addr;
    unsigned char type;
@@ -2519,15 +2524,21 @@ static void array_map (void)
 	goto return_error;
      }
 
+   num_elements = args[i_control].at->num_elements;
+
    if (-1 == _SLang_pop_datatype (&type))
      goto return_error;
 
-   at = args[i_control].at;
+   if (type == SLANG_UNDEFINED_TYPE)   /* Void_Type */
+     at = NULL;
+   else
+     {
+	at = args[i_control].at;
 
-   if (NULL == (at = SLang_create_array (type, 0, NULL, at->dims, at->num_dims)))
-     goto return_error;
-
-   num_elements = at->num_elements;
+	if (NULL == (at = SLang_create_array (type, 0, NULL, at->dims, at->num_dims)))
+	  goto return_error;
+     }
+   
 
    for (i = 0; i < num_args; i++)
      {
@@ -2537,11 +2548,20 @@ static void array_map (void)
 	  args[i].increment = ati->sizeof_type;
 	/* memset already guarantees increment to be zero */
 
+	if (ati->num_elements == 0)
+	  {
+	     SLang_verror (0, "array_map: function argument %d of %d is an empty array", 
+			   i+1, num_args);
+	     goto return_error;
+	  }
+
 	args[i].addr = (char *) ati->data;
      }
 
-   addr = (char *)at->data;
-   increment = at->sizeof_type;
+   if (at == NULL)
+     addr = NULL;
+   else
+     addr = (char *)at->data;
 
    for (i = 0; i < num_elements; i++)
      {
@@ -2572,13 +2592,17 @@ static void array_map (void)
 	if (-1 == SLexecute_function (nt))
 	  goto return_error;
 
+	if (at == NULL)
+	  continue;
+
 	if (-1 == at->cl->cl_apop (type, (VOID_STAR) addr))
 	  goto return_error;
 
-	addr += increment;
+	addr += at->sizeof_type;
      }
 
-   (void) SLang_push_array (at, 0);
+   if (at != NULL)
+     (void) SLang_push_array (at, 0);
 
    /* drop */
 
@@ -2592,8 +2616,6 @@ static void array_map (void)
 
 	SLfree ((char *) args);
      }
-
-   if (SLang_Error) SLang_push_null ();
 }
 
 static SLang_Intrin_Fun_Type Array_Table [] =
