@@ -1,4 +1,4 @@
-/* Copyright (c) 1992, 1999 John E. Davis
+/* Copyright (c) 1992, 1999, 2001 John E. Davis
  * This file is part of the S-Lang library.
  *
  * You may distribute under the terms of either the GNU General Public
@@ -100,6 +100,7 @@ static int Can_Background_Color_Erase = 1;
 
 /* -1 means unknown */
 int SLtt_Has_Status_Line = -1;	       /* hs */
+int SLang_TT_Write_FD = -1;
 
 static int Automatic_Margins;
 /* static int No_Move_In_Standout; */
@@ -234,7 +235,7 @@ static unsigned char *Output_Bufferp = Output_Buffer;
 
 unsigned long SLtt_Num_Chars_Output;
 
-static int sl_usleep (unsigned long usecs)
+int _SLusleep (unsigned long usecs)
 {
 #if !defined(VMS) || (__VMS_VER >= 70000000)
    struct timeval tv;
@@ -257,21 +258,21 @@ int SLtt_flush_output (void)
    total = 0;
    while (n > 0)
      {
-	nwrite = write (fileno(stdout), (char *) Output_Buffer + total, n);
+	nwrite = write (SLang_TT_Write_FD, (char *) Output_Buffer + total, n);
 	if (nwrite == -1)
 	  {
 	     nwrite = 0;
 #ifdef EAGAIN
 	     if (errno == EAGAIN)
 	       {
-		  sl_usleep (100000);   /* 1/10 sec */
+		  _SLusleep (100000);   /* 1/10 sec */
 		  continue;
 	       }
 #endif
 #ifdef EWOULDBLOCK
 	     if (errno == EWOULDBLOCK)
 	       {
-		  sl_usleep (100000);
+		  _SLusleep (100000);
 		  continue;
 	       }
 #endif
@@ -871,7 +872,7 @@ void SLtt_beep (void)
 	  {
 	     tt_write_string ("\033[?5h");
 	     SLtt_flush_output ();
-	     sl_usleep (50000);
+	     _SLusleep (50000);
 	     tt_write_string ("\033[?5l");
 	  }
 #endif
@@ -2065,6 +2066,12 @@ int SLtt_initialize (char *term)
    int is_xterm;
    int almost_vtxxx;
 
+   if (SLang_TT_Write_FD == -1)
+     {
+	/* Apparantly, this cannot fail according to the man pages. */
+	SLang_TT_Write_FD = fileno (stdout);
+     }
+   
    if (term == NULL)
      {
 	term = getenv ("TERM");
@@ -2541,9 +2548,12 @@ void SLtt_get_screen_size (void)
 	if (s != NULL) c = atoi (s);
      }
 
+   if (r <= 0) r = 24;
+   if (c <= 0) c = 80;
+#if 0
    if ((r <= 0) || (r > 200)) r = 24;
    if ((c <= 0) || (c > 250)) c = 80;
-
+#endif
    SLtt_Screen_Rows = r;
    SLtt_Screen_Cols = c;
 }
