@@ -1,6 +1,6 @@
 /* This module implements an interface to posix system calls */
 /* file stdio intrinsics for S-Lang */
-/* Copyright (c) 1992, 1999 John E. Davis
+/* Copyright (c) 1992, 1999, 2001 John E. Davis
  * This file is part of the S-Lang library.
  *
  * You may distribute under the terms of either the GNU General Public
@@ -222,6 +222,48 @@ SLFile_FD_Type *SLfile_create_fd (char *name, int fd)
    return f;
 }
 
+SLFile_FD_Type *SLfile_dup_fd (SLFile_FD_Type *f0)
+{
+   SLFile_FD_Type *f;
+   int fd0, fd;
+
+   if (f0 == NULL)
+     return NULL;
+   fd0 = f0->fd;
+   if (-1 == check_fd (fd0))
+     return NULL;
+
+   while (-1 == (fd = dup (fd0)))
+     {
+#ifdef EINTR
+	if (errno == EINTR)
+	  continue;
+#endif
+	_SLerrno_errno = errno;
+	return NULL;
+     }
+   
+   if (NULL == (f = SLfile_create_fd (f0->name, fd)))
+     {
+	f0->close (fd);
+	return NULL;
+     }
+   
+   return f;
+}
+
+int SLfile_get_fd (SLFile_FD_Type *f, int *fd)
+{
+   if (f == NULL)
+     return -1;
+   
+   *fd = f->fd;
+   if (-1 == check_fd (*fd))
+     return -1;
+
+   return 0;
+}
+
 void SLfile_free_fd (SLFile_FD_Type *f)
 {
    if (f == NULL)
@@ -392,6 +434,15 @@ static int posix_isatty (void)
    return ret;
 }
 
+static void posix_dup (SLFile_FD_Type *f)
+{
+   if ((NULL == (f = SLfile_dup_fd (f)))
+       || (-1 == SLfile_push_fd (f)))
+     SLang_push_null ();
+   
+   SLfile_free_fd (f);
+}
+	
 #define I SLANG_INT_TYPE
 #define V SLANG_VOID_TYPE
 #define F SLANG_FILE_FD_TYPE
@@ -409,6 +460,7 @@ static SLang_Intrin_Fun_Type Fd_Name_Table [] =
    MAKE_INTRINSIC_3("lseek", posix_lseek, L, F, L, I),
    MAKE_INTRINSIC_2("fdopen", posix_fdopen, V, F, S),
    MAKE_INTRINSIC_2("write", posix_write, V, F, B),
+   MAKE_INTRINSIC_1("dup_fd", posix_dup, V, F),
    MAKE_INTRINSIC_1("close", posix_close, I, F),
    SLANG_END_INTRIN_FUN_TABLE
 };
