@@ -1,4 +1,4 @@
-/* Copyright (c) 1996, 1999 John E. Davis
+/* Copyright (c) 1996, 1999, 2001 John E. Davis
  * This file is part of the S-Lang library.
  *
  * You may distribute under the terms of either the GNU General Public
@@ -138,10 +138,10 @@ static int SLwildcard (char *pattern, char *string)
 }
 /*}}}*/
 
-#if defined(__unix__) || defined(VMS) || defined(__WIN32__)
-# define MAX_DEFINES 64
-#else
+#if defined(__16_BIT_SYSTEM__)
 # define MAX_DEFINES 10
+#else
+# define MAX_DEFINES 128
 #endif
 
 /* The extra one is for NULL termination */
