@@ -1,5 +1,5 @@
 /* Basic type operations for S-Lang */
-/* Copyright (c) 1992, 1996 John E. Davis
+/* Copyright (c) 1992, 1996, 2001 John E. Davis
  * This file is part of the S-Lang library.
  *
  * You may distribute under the terms of either the GNU General Public
@@ -884,6 +884,12 @@ int _SLregister_types (void)
    if (-1 == SLclass_register_class (cl, SLANG_UNDEFINED_TYPE, sizeof (int),
 				     SLANG_CLASS_TYPE_SCALAR))
      return -1;
+   /* Make Void_Type a synonym for Undefined_Type.  Note that this does 
+    * not mean that Void_Type represents SLANG_VOID_TYPE.  Void_Type is 
+    * used by array_map to indicate no array is to be created.
+    */
+   if (-1 == SLclass_create_synonym ("Void_Type", SLANG_UNDEFINED_TYPE))
+     return -1;
 
    if (-1 == _SLarith_register_types ())
      return -1;
