@@ -7,9 +7,11 @@
 # define HAVE_FPSETMASK 1
 #endif
 
+static int Ignore_Exit = 0;
 static void c_exit (int *code)
 {
-   exit (*code);
+   if (Ignore_Exit == 0)
+     exit (*code);
 }
 
 static SLang_Intrin_Fun_Type Intrinsics [] =
@@ -21,6 +23,8 @@ static SLang_Intrin_Fun_Type Intrinsics [] =
 
 int main (int argc, char **argv)
 {
+   int i;
+
    if (argc < 2)
      {
 	fprintf (stderr, "Usage: %s FILE...\n", argv[0]);
@@ -40,9 +44,15 @@ int main (int argc, char **argv)
    fpsetmask (~(FP_X_OFL|FP_X_INV|FP_X_DZ|FP_X_DNML|FP_X_UFL|FP_X_IMP));
 #endif
 
-   if (-1 == SLang_load_file (argv[1]))
-     return 1;
-   
+   if (argc > 2)
+     Ignore_Exit = 1;
+
+   for (i = 1; i < argc; i++)
+     {
+	if (-1 == SLang_load_file (argv[i]))
+	  return 1;
+     }
+
    return SLang_Error;
 }
 
